Witness: WIP
[metze/wireshark/wip.git] / cfile.h
diff --git a/cfile.h b/cfile.h
index 163f4ca426d6376a51faab0e2f1ba865642689d5..5f4516f14629be6b350fe2efb3c97e62fa551765 100644 (file)
--- a/cfile.h
+++ b/cfile.h
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef __CFILE_H__
 #define __CFILE_H__
 
-#include "frame_data_sequence.h"
+#include <epan/epan.h>
+#include <epan/column-info.h>
+#include <epan/dfilter/dfilter.h>
+#include <epan/frame_data.h>
+#include <epan/frame_data_sequence.h>
+#include <wiretap/wtap.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
 
 /* Current state of file. */
 typedef enum {
@@ -37,9 +46,9 @@ typedef enum {
 
 /* Character set for text search. */
 typedef enum {
-  SCS_ASCII_AND_UNICODE,
-  SCS_ASCII,
-  SCS_UNICODE
+  SCS_NARROW_AND_WIDE,
+  SCS_NARROW,
+  SCS_WIDE
   /* add EBCDIC when it's implemented */
 } search_charset_t;
 
@@ -48,29 +57,28 @@ typedef enum {
   SD_BACKWARD
 } search_direction;
 
-/*
- * We store the frame_data structures in a radix tree, with 1024
- * elements per level.  The leaf nodes are arrays of 1024 frame_data
- * structures; the nodes above them are arrays of 1024 pointers to
- * the nodes below them.  The capture_file structure has a pointer
- * to the root node.
- *
- * As frame numbers are 32 bits, and as 1024 is 2^10, that gives us
- * up to 4 levels of tree.
- */
-#define LOG2_NODES_PER_LEVEL   10
-#define NODES_PER_LEVEL                (1<<LOG2_NODES_PER_LEVEL)
+#ifdef WANT_PACKET_EDITOR
+/* XXX, where this struct should go? */
+typedef struct {
+  struct wtap_pkthdr phdr; /**< Modified packet header */
+  char *pd;                /**< Modified packet data */
+} modified_frame_data;
+#endif
 
 typedef struct _capture_file {
+  epan_t      *epan;
   file_state   state;           /* Current state of capture file */
   gchar       *filename;        /* Name of capture file */
   gchar       *source;          /* Temp file source, e.g. "Pipe from elsewhere" */
   gboolean     is_tempfile;     /* Is capture file a temporary file? */
-  gboolean     user_saved;      /* If capture file is temporary, has it been saved by user yet? */
+  gboolean     unsaved_changes; /* Does the capture file have changes that have not been saved? */
   gint64       f_datalen;       /* Size of capture file data (uncompressed) */
   guint16      cd_t;            /* File type of capture file */
-  int          lnk_t;           /* Link-layer type with which to save capture */
+  gboolean     iscompressed;    /* TRUE if the file is compressed */
+  int          lnk_t;           /* File link-layer type; could be WTAP_ENCAP_PER_PACKET */
+  GArray      *linktypes;       /* Array of packet link-layer types */
   guint32      count;           /* Total number of frames */
+  guint64      packet_comment_count; /* Number of comments in frames (could be >1 per frame... */
   guint32      displayed_count; /* Number of displayed frames */
   guint32      marked_count;    /* Number of marked frames */
   guint32      ignored_count;   /* Number of ignored frames */
@@ -81,7 +89,8 @@ typedef struct _capture_file {
   gboolean     has_snap;        /* TRUE if maximum capture packet length is known */
   int          snap;            /* Maximum captured packet length */
   wtap        *wth;             /* Wiretap session */
-  dfilter_t   *rfcode;          /* Compiled read (display) filter program */
+  dfilter_t   *rfcode;          /* Compiled read filter program */
+  dfilter_t   *dfcode;          /* Compiled display filter program */
   gchar       *dfilter;         /* Display filter string */
   gboolean     redissecting;    /* TRUE if currently redissecting (cf_redissect_packets) */
   /* search */
@@ -97,13 +106,14 @@ typedef struct _capture_file {
   search_direction dir;         /* Direction in which to do searches */
   gboolean     search_in_progress; /* TRUE if user just clicked OK in the Find dialog or hit <control>N/B */
   /* packet data */
-  union wtap_pseudo_header pseudo_header; /* Packet pseudo_header */
-  guint8       pd[WTAP_MAX_PACKET_SIZE];  /* Packet data */
+  struct wtap_pkthdr phdr;                /* Packet header */
+  Buffer       buf;             /* Packet data */
   /* frames */
   frame_data_sequence *frames;  /* Sequence of frames, if we're keeping that information */
   guint32      first_displayed; /* Frame number of first frame displayed */
   guint32      last_displayed;  /* Frame number of last frame displayed */
   column_info  cinfo;           /* Column formatting information */
+  gboolean     columns_changed; /**< Have the columns been changed in the prefs? */
   frame_data  *current_frame;   /* Frame data for current frame */
   gint         current_row;     /* Row number for current frame */
   epan_dissect_t *edt;          /* Protocol dissection for currently selected packet */
@@ -111,8 +121,22 @@ typedef struct _capture_file {
 #ifdef WANT_PACKET_EDITOR
   GTree       *edited_frames;   /* BST with modified frames */
 #endif
+  gpointer     window;         /* Top-level window associated with file */
+  GTree       *frames_user_comments;   /* BST with user comments for frames (key = frame_data) */
+  gulong       computed_elapsed;
+
+  guint32      cum_bytes;
+  const frame_data *ref;
+  frame_data  *prev_dis;
+  frame_data  *prev_cap;
 } capture_file;
 
 extern void cap_file_init(capture_file *cf);
 
+extern const char *cap_file_get_interface_name(void *data, guint32 interface_id);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif /* cfile.h */